/*
 * Copyright 2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.test.mock;

import java.lang.reflect.InvocationTargetException;
import java.util.Map;

import javax.faces.el.EvaluationException;
import javax.faces.el.PropertyNotFoundException;
import javax.faces.el.PropertyResolver;

import org.apache.commons.beanutils.PropertyUtils;

/**
 * <p>Mock implementation of <code>PropertyResolver</code>.</p>
 *
 * $Id$
 */

public class MockPropertyResolver extends PropertyResolver {


    // ------------------------------------------------------------ Constructors


    /**
     * <p>Construct a default instance.</p>
     */
    public MockPropertyResolver() {
    }


    // ----------------------------------------------------- Mock Object Methods


    // ------------------------------------------------------ Instance Variables


    // ------------------------------------------------ PropertyResolver Methods


    /** {@inheritDoc} */
    public Object getValue(Object base, Object property)
        throws EvaluationException, PropertyNotFoundException {

        if (base == null) {
            throw new NullPointerException();
        }
        String name = property.toString();
        try {
            if (base instanceof Map) {
                Map map = (Map) base;
                if (map.containsKey(name)) {
                    return map.get(name);
                } else {
                    throw new PropertyNotFoundException(name);
                }
            } else {
                return PropertyUtils.getSimpleProperty(base, name);
            }
        } catch (IllegalAccessException e) {
            throw new EvaluationException(e);
        } catch (InvocationTargetException e) {
            throw new EvaluationException(e.getTargetException());
        } catch (NoSuchMethodException e) {
            throw new PropertyNotFoundException(name);
        }

    }


    /** {@inheritDoc} */
    public Object getValue(Object base, int index)
        throws PropertyNotFoundException {

        return getValue(base, "" + index);

    }


    /** {@inheritDoc} */
    public void setValue(Object base, Object property, Object value)
        throws PropertyNotFoundException {

        if (base == null) {
            throw new NullPointerException();
        }
        String name = property.toString();
        try {
            if (base instanceof Map) {
                ((Map) base).put(name, value);
            } else {
                PropertyUtils.setSimpleProperty(base, name, value);
            }
        } catch (IllegalAccessException e) {
            throw new EvaluationException(e);
        } catch (InvocationTargetException e) {
            throw new EvaluationException(e.getTargetException());
        } catch (NoSuchMethodException e) {
            throw new PropertyNotFoundException(name);
        }

    }


    /** {@inheritDoc} */
    public void setValue(Object base, int index, Object value)
        throws PropertyNotFoundException {

        setValue(base, "" + index, value);

    }


    /** {@inheritDoc} */
    public boolean isReadOnly(Object base, Object property)
        throws PropertyNotFoundException {

        if (base == null) {
            throw new NullPointerException();
        }
        String name = property.toString();
        return !PropertyUtils.isWriteable(base, name);

    }


    /** {@inheritDoc} */
    public boolean isReadOnly(Object base, int index)
        throws PropertyNotFoundException {

        return isReadOnly(base, "" + index);

    }


    /** {@inheritDoc} */
    public Class getType(Object base, Object property)
        throws PropertyNotFoundException {

        if (base == null) {
            throw new NullPointerException();
        }
        String name = property.toString();
        try {
            return PropertyUtils.getPropertyType(base, name);
        } catch (IllegalAccessException e) {
            throw new EvaluationException(e);
        } catch (InvocationTargetException e) {
            throw new EvaluationException(e.getTargetException());
        } catch (NoSuchMethodException e) {
            throw new PropertyNotFoundException(name);
        }

    }


    /** {@inheritDoc} */
    public Class getType(Object base, int index)
        throws PropertyNotFoundException {

        return getType(base, "" + index);

    }


}
